@@ -22,6 +22,7 @@
 #include <mach/board.h>
 #include <mach/at91sam9_smc.h>
 #include <gpio.h>
+#include <mach/iomux.h>
 #include <mach/io.h>
 #include <mach/at91_pmc.h>
 #include <mach/at91_rstc.h>
@@ -122,6 +123,8 @@ static void animeo_ip_add_device_nand(void)
 
 static struct macb_platform_data macb_pdata = {
 	.phy_addr = 0,
+	.phy_interface = PHY_INTERFACE_MODE_MII,
+	.flags = AT91SAM_ETX2_ETX3_ALTERNATIVE,
 };
 
 /*
@@ -245,6 +248,10 @@ static int animeo_ip_console_init(void)
 	 */
 #define ATMEL_US_BRGR	0x0020
 	at91_sys_write(AT91_DBGU + ATMEL_US_BRGR, 0);
+
+	barebox_set_model("Somfy Animeo IP");
+	barebox_set_hostname("animeoip");
+
 	at91_register_uart(3, 0);
 	return 0;
 }
