@@ -32,6 +32,7 @@
 #include <linux/mtd/nand.h>
 #include <mach/at91_pmc.h>
 #include <mach/board.h>
+#include <mach/iomux.h>
 #include <gpio.h>
 #include <mach/io.h>
 #include <mach/at91sam9_smc.h>
@@ -279,6 +280,9 @@ device_initcall(at91sam9263ek_devices_init);
 
 static int at91sam9263ek_console_init(void)
 {
+	barebox_set_model("Atmel at91sam9263-ek");
+	barebox_set_hostname("at91sam9263-ek");
+
 	at91_register_uart(0, 0);
 	return 0;
 }
