@@ -19,6 +19,7 @@
 #include <common.h>
 #include <net.h>
 #include <init.h>
+#include <gpio.h>
 #include <environment.h>
 #include <asm/armlinux.h>
 #include <generated/mach-types.h>
@@ -31,7 +32,7 @@
 #include <linux/mtd/nand.h>
 #include <mach/at91_pmc.h>
 #include <mach/board.h>
-#include <mach/gpio.h>
+#include <mach/iomux.h>
 #include <mach/io.h>
 #include <mach/at91sam9_smc.h>
 #include <dm9000.h>
@@ -157,6 +158,9 @@ device_initcall(pm9261_devices_init);
 
 static int pm9261_console_init(void)
 {
+	barebox_set_model("Ronetix PM9261");
+	barebox_set_hostname("pm9261");
+
 	at91_register_uart(0, 0);
 	return 0;
 }
