@@ -11,11 +11,12 @@
  *
  */
 #include <common.h>
+#include <gpio.h>
 #include <asm/armlinux.h>
 #include <mach/hardware.h>
 #include <mach/at91rm9200.h>
 #include <mach/board.h>
-#include <mach/gpio.h>
+#include <mach/iomux.h>
 #include <mach/io.h>
 #include <mach/at91rm9200_mc.h>
 #include <i2c/i2c-gpio.h>
