@@ -1,16 +1,15 @@
 #ifndef _GENERIC_NAMES_H_
 #define _GENERIC_NAMES_H_
 
-#define CONFIG_SYS_CLK_FREQ		20000000
+#define CONFIG_SYS_CLK_FREQ		50000000
 
-#define OPENRISC_TIMER_FREQ		20000000
+#define OPENRISC_TIMER_FREQ		CONFIG_SYS_CLK_FREQ
 
 #define OPENRISC_SOPC_MEMORY_BASE	0x00000000
 #define OPENRISC_SOPC_MEMORY_SIZE	0x02000000
 
+#define OPENRISC_SOPC_UART_FREQ		CONFIG_SYS_CLK_FREQ
 #define OPENRISC_SOPC_UART_BASE		0x90000000
-#define CONFIG_SYS_UART_FREQ		CONFIG_SYS_CLK_FREQ
-#define CONFIG_SYS_UART_BAUD		115200
 
 /* We reserve 256K for barebox */
 #define BAREBOX_RESERVED_SIZE		0x40000
