@@ -21,6 +21,10 @@
  *
  */
 
+#ifdef CONFIG_DEBUG_INITCALLS
+#define DEBUG
+#endif
+
 /**
  * @file
  * @brief Main entry into the C part of barebox
