@@ -4,7 +4,7 @@
 #include <param.h>
 
 #ifdef CONFIG_GLOBALVAR
-int globalvar_add_simple(const char *name);
+int globalvar_add_simple(const char *name, const char *value);
 
 int globalvar_add(const char *name,
 		int (*set)(struct device_d *dev, struct param_d *p, const char *val),
@@ -13,7 +13,7 @@ int globalvar_add(const char *name,
 char *globalvar_get_match(const char *match, const char *separator);
 void globalvar_set_match(const char *match, const char *val);
 #else
-static inline int globalvar_add_simple(const char *name)
+static inline int globalvar_add_simple(const char *name, const char *value)
 {
 	return 0;
 }
